@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
 
 package IO::Socket::Netlink;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Socket );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 
@@ -57,7 +57,9 @@ extend.
 
 =head1 CLASS METHODS
 
-=head2 $class->register_protocol( $proto )
+=head2 register_protocol
+
+   $class->register_protocol( $proto )
 
 May be called by a subclass implementing a Netlink protocol. If so, then any
 object constructed using a known protocol on this base class will be
@@ -77,7 +79,9 @@ sub register_protocol
 
 =cut
 
-=head2 $sock = IO::Socket::Netlink->new( %args )
+=head2 new
+
+   $sock = IO::Socket::Netlink->new( %args )
 
 Creates a new C<IO::Socket::Netlink> object.
 
@@ -137,7 +141,9 @@ sub configure
 
 =cut
 
-=head2 $pid = $sock->sockpid
+=head2 sockpid
+
+   $pid = $sock->sockpid
 
 Returns the socket identifier
 
@@ -149,7 +155,9 @@ sub sockpid
    ( unpack_sockaddr_nl( $self->sockname ) )[0];
 }
 
-=head2 $groups = $sock->sockgroups
+=head2 sockgroups
+
+   $groups = $sock->sockgroups
 
 Returns the 32bit bitmask of multicast groups
 
@@ -173,7 +181,9 @@ sub command_class
    return shift->message_class;
 }
 
-=head2 $msg = $sock->new_message( %args )
+=head2 new_message
+
+   $msg = $sock->new_message( %args )
 
 Returns a new message object containing the given arguments. The named
 arguments are in fact read as an list of key/value pairs, not a hash, so order
@@ -190,7 +200,9 @@ sub new_message
    return $self->message_class->new( @_ );
 }
 
-=head2 $msg = $sock->new_request( %args )
+=head2 new_request
+
+   $msg = $sock->new_request( %args )
 
 A convenience wrapper around C<new_message> which sets the C<NLM_F_REQUEST>
 flag on the returned message.
@@ -205,7 +217,9 @@ sub new_request
    return $message;
 }
 
-=head2 $sock->new_command( %args )
+=head2 new_command
+
+   $sock->new_command( %args )
 
 As C<new_request>, but may use a different class for messages. This is for
 such netlink protocols as C<TASKSTATS>, which uses a different set of message
@@ -229,7 +243,9 @@ sub unpack_message
    return $self->message_class->unpack( @_ );
 }
 
-=head2 $sock->send_nlmsg( $message )
+=head2 send_nlmsg
+
+   $sock->send_nlmsg( $message )
 
 Sends the given message object to the kernel. C<$message> should be a message
 object, constructed using the socket's C<new_message> factory method.
@@ -244,7 +260,9 @@ sub send_nlmsg
    $self->send( $message->pack );
 }
 
-=head2 $sock->recv_nlmsg( $message, $maxlen )
+=head2 recv_nlmsg
+
+   $sock->recv_nlmsg( $message, $maxlen )
 
 Receives a single message from the kernel. The C<$message> parameter should be
 a variable, which will contain the new message object when this method returns
@@ -279,7 +297,9 @@ sub recv_nlmsg
    return $ret;
 }
 
-=head2 $sock->recv_nlmsgs( \@messages, $maxlen )
+=head2 recv_nlmsgs
+
+   $sock->recv_nlmsgs( \@messages, $maxlen )
 
 Receives message from the kernel. If the first message received has the
 C<NLM_F_MULTI> flag, then messages will be collected up until the final
@@ -336,11 +356,14 @@ use Socket::Netlink qw(
    pack_nlmsghdr unpack_nlmsghdr pack_nlattrs unpack_nlattrs
 );
 
-# Don't hard-depend on Sub::Name since it's only a niceness for stack traces
+# Don't hard-depend on Sub::Name or Sub::Util since it's only a niceness for stack traces
 BEGIN {
    if( eval { require Sub::Name } ) {
       *subname = \&Sub::Name::subname;
    }
+   elsif( eval { require Sub::Util } ) {
+      *subname = \&Sub::Util::set_subname;
+   }
    else {
       # Ignore the name, return the CODEref
       *subname = sub { return $_[1] };
