@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
 
 package IO::Socket::Netlink::Generic;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Socket::Netlink );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 
@@ -44,7 +44,9 @@ generic families to extend.
 
 =head1 CLASS METHODS
 
-=head2 $class->register_family_name( $name )
+=head2 register_family_name
+
+   $class->register_family_name( $name )
 
 Must be called by a subclass implementing a particular protocol family, to
 declare its family name. The first time a socket in that class is constructed,
@@ -119,7 +121,9 @@ sub message_class
 
 =cut
 
-=head2 $family = $sock->get_family_by_name( $name )
+=head2 get_family_by_name
+
+   $family = $sock->get_family_by_name( $name )
 
 =cut
 
@@ -131,7 +135,9 @@ sub get_family_by_name
    return $self->_get_family( name => $name );
 }
 
-=head2 $family = $sock->get_family_by_id( $id )
+=head2 get_family_by_id
+
+   $family = $sock->get_family_by_id( $id )
 
 =cut
 
