@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
 
 package Socket::Netlink;
 
@@ -10,7 +10,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -88,11 +88,15 @@ A 32-bit bitmask of the multicast groups to join.
 
 =back
 
-=head2 $addr = pack_sockaddr_nl( $pid, $groups )
+=head2 pack_sockaddr_nl
+
+   $addr = pack_sockaddr_nl( $pid, $groups )
 
 Returns a C<sockaddr_nl> structure with the fields packed into it.
 
-=head2 ( $pid, $groups ) = unpack_sockaddr_nl( $addr )
+=head2 unpack_sockaddr_nl
+
+   ( $pid, $groups ) = unpack_sockaddr_nl( $addr )
 
 Takes a C<sockaddr_nl> structure and returns the unpacked fields from it.
 
@@ -102,9 +106,13 @@ Takes a C<sockaddr_nl> structure and returns the unpacked fields from it.
 
 The following function pairs operate on structure types used by netlink
 
-=head2 $buffer = pack_nlmsghdr( $type, $flags, $seq, $pid, $body )
+=head2 pack_nlmsghdr
 
-=head2 ( $type, $flags, $seq, $pid, $body, $morebuffer ) = unpack_nlmsghdr( $buffer )
+   $buffer = pack_nlmsghdr( $type, $flags, $seq, $pid, $body )
+
+=head2 unpack_nlmsghdr
+
+   ( $type, $flags, $seq, $pid, $body, $morebuffer ) = unpack_nlmsghdr( $buffer )
 
 Pack or unpack a C<struct nlmsghdr> and its payload body.
 
@@ -121,17 +129,25 @@ C<$morebuffer> list element will not be returned.
 There is no similar functionallity for C<pack_nlmsghdr>; simply concatenate
 multiple results together to send more than one message.
 
-=head2 $buffer = pack_nlmsgerr( $error, $msg )
+=head2 pack_nlmsgerr
 
-=head2 ( $error, $msg ) = unpack_nlmsgerr( $buffer )
+   $buffer = pack_nlmsgerr( $error, $msg )
+
+=head2 unpack_nlmsgerr
+
+   ( $error, $msg ) = unpack_nlmsgerr( $buffer )
 
 Pack or unpack a C<struct nlmsgerr>. The kernel expects or reports negative
 integers in its structures; these functions take or return normal positive
 error values suitable for use with C<$!>.
 
-=head2 $buffer = pack_nlattrs( %attrs )
+=head2 pack_nlattrs
 
-=head2 %attrs = unpack_nlattrs( $buffer )
+   $buffer = pack_nlattrs( %attrs )
+
+=head2 unpack_nlattrs
+
+   %attrs = unpack_nlattrs( $buffer )
 
 Pack or unpack a list of netlink attributes.
 
